/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from ITIM 4.6 Base to FP14 (L3_itim_46_5763)
 *
 **********************************************************/

ALTER TABLE AUDIT_EVENT
  ALTER COLUMN ENTITY_NAME NVARCHAR(1000);

ALTER TABLE AUDIT_EVENT
  ALTER COLUMN INITIATOR_NAME  NVARCHAR(1000);

ALTER TABLE AUDIT_EVENT
  ALTER COLUMN CONTAINER_NAME  NVARCHAR(1000);

ALTER TABLE AUDIT_MGMT_TARGET
  ALTER COLUMN TARGET_ENTITY_NAME  NVARCHAR(1000);

ALTER TABLE AUDIT_MGMT_PROVISIONING
  ALTER COLUMN OWNER_NAME  NVARCHAR(1000);

ALTER TABLE AUDIT_MGMT_PROVISIONING
  ALTER COLUMN SERVICE_NAME  NVARCHAR(1000);

ALTER TABLE AUDIT_MGMT_DELEGATE
  ALTER COLUMN DELEGATE_NAME  NVARCHAR(1000);

/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from FP14 to FP25 (L3_itim_46_5791)
 *
 * Note: Refer to upgradeData.ddl for the DB data changes
 *
 **********************************************************/

ALTER TABLE RESOURCE_PROVIDERS ADD SERVER NVARCHAR(20);

CREATE TABLE SUMMARY_ORDER (
    RESULT_SUMMARY NVARCHAR(2) NOT NULL,
    RESULT_SEVERITY SMALLINT NOT NULL UNIQUE,
    CONSTRAINT Uni_ResultSummary PRIMARY KEY(RESULT_SUMMARY)
);


/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from FP25 to FP33 (L3_itim_46_5795)
 *
 **********************************************************/

ALTER TABLE ENTITLEMENT_PROVISIONINGPARAMS
  ALTER COLUMN ATTRIBUTEVALUE  VARCHAR(4000);




/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from the latest 4.6 fix pack level (FP33) to ITIM 5.0
 *
 **********************************************************/

/** v92 (L3) -> ITIM 5.0 */
ALTER TABLE RESOURCE_PROVIDERS
  ALTER COLUMN SERVER  NVARCHAR(255);


ALTER TABLE REMOTE_RESOURCES_RECONS
  ADD RECON_NAME NVARCHAR (300),
      DESCRIPTION NVARCHAR (300);

ALTER TABLE REMOTE_RESOURCES_RECON_QUERIES
  ADD SUPPORT_DATA_ONLY SMALLINT;

ALTER TABLE PO_TOPIC_TABLE
  ALTER COLUMN SERVER  NVARCHAR(255);

ALTER TABLE SCHEDULED_MESSAGE
  ADD SMALL_MESSAGE NVARCHAR(4000);

ALTER TABLE SCHEDULED_MESSAGE
  ALTER COLUMN SERVER  NVARCHAR(255);

ALTER TABLE PROCESS
ADD SUBJECT_ACCESS_ID NVARCHAR(2000),
    SUBJECT_ACCESS_NAME NVARCHAR(100),
    SHORT_DETAIL NVARCHAR(4000);


ALTER TABLE ACTIVITY
  ADD SHORT_DETAIL NVARCHAR(4000);


ALTER TABLE PROCESSLOG
  ADD SMALL_NEW_DATA NVARCHAR(4000);


CREATE TABLE SERVICE_ACCOUNT_MAPPING (
  SERVICEPROFILE VARCHAR (255) NOT NULL,
  ACCOUNTPROFILE VARCHAR (255) NOT NULL,
  PRIMARY KEY (SERVICEPROFILE, ACCOUNTPROFILE)
);


ALTER TABLE RECONCILIATION
  ADD ACTIVITY_ID BIGINT;

ALTER TABLE RECONCILIATION_INFO
  ADD HANDLE BIGINT;


ALTER TABLE AUDIT_MGMT_PROVISIONING
  ADD access_name NVARCHAR (1000),
  	access_dn NVARCHAR (1000);

create table RECERTIFICATIONLOG
(
  PROCESS_ID BIGINT NOT NULL,
  ACTIVITY_ID BIGINT NOT NULL,
  ENTITY_DN VARCHAR(255),
  ACCESS_DN VARCHAR(255),
  ACCOUNT_ID VARCHAR(100),
  ACCOUNT_OWNER_NAME VARCHAR(100),
  ACCOUNT_OWNER VARCHAR(255),
  ACCESS_NAME VARCHAR(100),
  ACCESS_TYPE VARCHAR(100),
  TYPE VARCHAR(2) NOT NULL,
  SERVICE VARCHAR(255),
  SERVICE_NAME VARCHAR(100),
  SERVICE_PROFILE VARCHAR(100),
  PARTICIPANT VARCHAR(255),
  PARTICIPANT_NAME VARCHAR(100),
  PARTICIPANT_ID VARCHAR(100),
  RECERT_RESULT VARCHAR(2),
  ACTION VARCHAR(2),
  COMMENTS VARCHAR(2000),
  STARTED VARCHAR(50),
  COMPLETED VARCHAR(50),
  RESULT_SUMMARY VARCHAR(2),
  TENANT VARCHAR(255),
  CONSTRAINT RECERT_PK PRIMARY KEY(PROCESS_ID, ACTIVITY_ID)
);

CREATE TABLE SCRIPT  (
  TYPE CHAR(1) NOT NULL,
  ID VARCHAR(50) NOT NULL,
  JOIN_ORDER SMALLINT NOT NULL,
  PERSON_ATTRIBUTE VARCHAR(100) NOT NULL,
  FIRST_LAST SMALLINT,
  CONCATENATE_CHAR CHAR(10),
  CONSTRAINT SCRIPT_PK PRIMARY KEY(TYPE, ID, JOIN_ORDER)
);

DROP VIEW ROOTPROCESSVIEW;

CREATE VIEW ROOTPROCESSVIEW (ID, TYPE, REQUESTER) AS
(
  SELECT ID, TYPE, REQUESTER
  FROM PROCESS
  WHERE  PROCESS.ROOT_PROCESS_ID  = 0
  OR PROCESS.ROOT_PROCESS_ID  = PROCESS.ID
  AND PROCESS.TYPE IN ('OP','AA','AC','UA','UC','UD','US','UR','UO','SR','OA','OC','AD',
            'AS','AR','AP','LO','AO','LS','LR','LP','LD','MS','MR','MD','DA','DC',
            'DD','PA','PC','PD','SA','SC','SD','PS','EN','RC','PE','LC','CP','EP','RP','SM','MA','EA','ER','HR')
);

DROP VIEW SUBPROCESSVIEW;

CREATE VIEW SUBPROCESSVIEW (ROOT_PROCESS_ID, SUBMITTED, COMPLETED, SUBJECT_PROFILE,
  SUBJECT_SERVICE, SUBJECT, TYPE, REQUESTER, RESULT_SUMMARY)
AS
(
  SELECT ROOT_PROCESS_ID, SUBMITTED, COMPLETED, SUBJECT_PROFILE,
    SUBJECT_SERVICE, SUBJECT, TYPE, REQUESTER,
    CASE
      WHEN RESULT_SUMMARY = '' THEN 'PE'
      ELSE RESULT_SUMMARY
    END as RESULT_SUMMARY
  FROM PROCESS
  WHERE TYPE IN ('OA', 'OC', 'AD', 'AS', 'AR', 'AP')
);

DROP VIEW PENDING_APPROVAL;

CREATE VIEW PENDING_APPROVAL (PROCESSID, RESULT_SUMMARY)
AS
(
  SELECT PROCESS.ID,
    CASE
      WHEN WORKITEM.LOCK_OWNER IS NULL THEN ACTIVITY.RESULT_SUMMARY
      ELSE 'LK'
    END
  FROM PROCESS, ACTIVITY, WORKITEM
  WHERE WORKITEM.PROCESS_ID = PROCESS.ID AND WORKITEM.ACTIVITY_ID = ACTIVITY.ID
);

CREATE VIEW SUSPENDED_USERS (REQUESTEE, COMPLETED) AS
(
  SELECT PROCESS.REQUESTEE, MAX(PROCESS.COMPLETED)
  FROM PROCESS
  WHERE PROCESS.TYPE = 'US'
  GROUP BY PROCESS.REQUESTEE
);

CREATE VIEW SUSPENDED_ACCOUNT_OPERATIONS (REQUESTEE, SUBJECT_SERVICE, SUBJECT, SUBJECT_PROFILE, COMPLETED) AS
(
  SELECT PROCESS.REQUESTEE, PROCESS.SUBJECT_SERVICE, PROCESS.SUBJECT, PROCESS.SUBJECT_PROFILE, MAX(PROCESS.COMPLETED)
  FROM PROCESS
  WHERE PROCESS.TYPE = 'AS'
  GROUP BY PROCESS.REQUESTEE, PROCESS.SUBJECT_SERVICE, PROCESS.SUBJECT, PROCESS.SUBJECT_PROFILE
);

CREATE VIEW PROCESS_VIEW (ID, REQUESTER, REQUESTEE)
AS
(
  SELECT PROCESS.ID, COALESCE(PROCESS.REQUESTER, ' ') as REQUESTER, COALESCE(PROCESS.REQUESTEE, ' ') as REQUESTEE
  FROM PROCESS
);

CREATE TABLE MANUAL_SERVICE_RECON_ACCOUNTS (
  GLOBAL_ID VARCHAR(255) NOT NULL,
  ACCOUNTS NTEXT,
  PRIMARY KEY (GLOBAL_ID)
);


CREATE TABLE VIEW_DEFINITION (
  ID INT NOT NULL,
  NAME VARCHAR(100),
  DESCRIPTION VARCHAR(2000),
  CONSTRAINT VIEW_DEFINITION_PK PRIMARY KEY(ID)
);


CREATE TABLE TASKS_VIEWABLE (
  TASK_ID VARCHAR(255) NOT NULL,
  VIEW_ID INT NOT NULL,
  VIEWABLE CHAR(1) NOT NULL DEFAULT 'N',
  CONSTRAINT TASKS_VIEWABLE_PK PRIMARY KEY(TASK_ID, VIEW_ID),
  CONSTRAINT VIEW_ID_FK FOREIGN KEY (VIEW_ID) REFERENCES VIEW_DEFINITION (ID)
);

ALTER TABLE BULK_DATA_SERVICE
  ADD filename NVARCHAR(255),
      DESCNAME NVARCHAR(255);

ALTER TABLE MIGRATION_STATUS
  ADD SERVICEID BIGINT;

CREATE TABLE COMMON_TASKS  (
	PERSONA VARCHAR(100) NOT NULL,
	TASK_ID VARCHAR(255) NOT NULL,
	CONSTRAINT COMMON_TASKS_PK PRIMARY KEY(PERSONA, TASK_ID)
);

CREATE TABLE ACTIVITY_LOCK (
  PROCESS_ID  BIGINT NOT NULL,
  ACTIVITY_ID   BIGINT NOT NULL,
  SERVER NVARCHAR(255) NOT NULL,
  THREAD_ID BIGINT NOT NULL,
  LOCK_COUNT INT,
  CONSTRAINT ACTIVITY_LOCK_PK PRIMARY KEY(PROCESS_ID, ACTIVITY_ID, SERVER, THREAD_ID),
  CONSTRAINT ACTIVITY_LOCK_PFK FOREIGN KEY(PROCESS_ID) REFERENCES PROCESS(ID),
  CONSTRAINT ACTIVITY_LOCK_AFK FOREIGN KEY(ACTIVITY_ID) REFERENCES ACTIVITY(ID)
);

ALTER TABLE RESOURCE_PROVIDERS
  ADD RESOURCE_TEST_STATUS SMALLINT,
      LAST_TEST_STATUS_TIME DATETIME;
create index AUDIT_REPORT1 on AUDIT_EVENT (TIMESTAMP, ITIM_EVENT_CATEGORY);

/**********************************************************
 *
 *  The section below contains the database schema
 *  changes from ITIM 5.0 FP01 to FP02
 *
 **********************************************************/

CREATE TABLE PASSWORD_SYNCH (
	ACTIVITY_ID BIGINT NOT NULL,
	ACCOUNT_DN NVARCHAR(512),
	TIME_REQUESTED NVARCHAR(50),
	PASSWORD NVARCHAR(500),

	CONSTRAINT PWD_SYNCH_PK PRIMARY KEY(ACTIVITY_ID)
);

CREATE INDEX PS_ACCDN_X ON PASSWORD_SYNCH(ACCOUNT_DN);
CREATE INDEX PS_TIME_X ON PASSWORD_SYNCH(TIME_REQUESTED);

/**********************************************************
 *
 *  The section below contains the database schema
 *  changes in ITIM 5.1
 *
 **********************************************************/

CREATE TABLE ROLE_INHERITANCE (
  ASCENDENT NVARCHAR(2000) NOT NULL,
  DESCENDENT NVARCHAR(2000) NOT NULL,
  CONSTRAINT ROLE_INH_PK PRIMARY KEY(ASCENDENT, DESCENDENT)
);

CREATE INDEX ROLE_INH_ASC_IDX ON ROLE_INHERITANCE (ASCENDENT ASC) ;
CREATE INDEX ROLE_INH_DSC_IDX ON ROLE_INHERITANCE (DESCENDENT ASC) ;

CREATE TABLE USERRECERT_HISTORY (
  ID BIGINT NOT NULL,
  PROCESS_ID BIGINT NOT NULL,
  ACTIVITY_ID BIGINT NOT NULL,
  PERSON_DN NVARCHAR(255),
  PERSON_NAME NVARCHAR(240),
  PERSON_PROFILE NVARCHAR(128),
  PERSON_EMAIL NVARCHAR(240),
  PERSON_CUSTOM_DISPLAY NVARCHAR(240),
  PERSON_STATUS INTEGER,
  PERSON_CONTAINER_DN NVARCHAR(255),
  PERSON_CONTAINER_NAME NVARCHAR(128),
  POLICY_DN NVARCHAR(255),
  POLICY_NAME NVARCHAR(240),
  SUBMITTED_DATE NVARCHAR(50),
  TIMEOUT SMALLINT,
  CONSTRAINT USERRECERT_PK PRIMARY KEY (ID)
);

ALTER TABLE USERRECERT_HISTORY ADD CONSTRAINT USERRECERT_PROC_FK FOREIGN KEY (PROCESS_ID) REFERENCES PROCESS (ID) ON DELETE CASCADE;
ALTER TABLE USERRECERT_HISTORY ADD CONSTRAINT USERRECERT_ACTV_FK FOREIGN KEY (ACTIVITY_ID) REFERENCES ACTIVITY (ID) ON DELETE CASCADE;

CREATE INDEX URH_SUBMITTED ON USERRECERT_HISTORY (SUBMITTED_DATE ASC);

CREATE TABLE USERRECERT_ROLE (
  ID BIGINT NOT NULL,
  RECERT_ID BIGINT NOT NULL,
  ROLE_DN NVARCHAR(255) NOT NULL,
  ROLE_NAME NVARCHAR(240),
  ROLE_DESCRIPTION NVARCHAR(500),
  DECISION CHAR(2),
  CONSTRAINT USERRECERT_ROLE_PK PRIMARY KEY (ID)
);

ALTER TABLE USERRECERT_ROLE ADD CONSTRAINT USERRECERT_ROLE_FK FOREIGN KEY (RECERT_ID) REFERENCES USERRECERT_HISTORY (ID) ON DELETE CASCADE;

CREATE INDEX URR_ID_DEC ON USERRECERT_ROLE (RECERT_ID ASC, DECISION ASC);

CREATE TABLE USERRECERT_ACCOUNT (
  ID BIGINT NOT NULL,
  RECERT_ID BIGINT NOT NULL,
  ACCOUNT_DN NVARCHAR(255) NOT NULL,
  ACCOUNT_UID NVARCHAR(240) NOT NULL,
  SERVICE_DN NVARCHAR(255) NOT NULL,
  SERVICE_NAME NVARCHAR(240),
  SERVICE_DESCRIPTION NVARCHAR(240),
  DECISION CHAR(2),
  CONSTRAINT USERRECERT_ACCT_PK PRIMARY KEY (ID)
);

ALTER TABLE USERRECERT_ACCOUNT ADD CONSTRAINT USERRECERT_ACCT_FK FOREIGN KEY (RECERT_ID) REFERENCES USERRECERT_HISTORY (ID) ON DELETE CASCADE;

CREATE INDEX URA_ID_DEC ON USERRECERT_ACCOUNT (RECERT_ID ASC, DECISION ASC);

CREATE TABLE USERRECERT_GROUP (
  ID BIGINT NOT NULL,
  RECERT_ID BIGINT NOT NULL,
  ACCOUNT_ID BIGINT NOT NULL,
  GROUP_DN NVARCHAR(500) NOT NULL,
  GROUP_NAME NVARCHAR(240),
  GROUP_DESCRIPTION NVARCHAR(500),
  DECISION CHAR(2),
  CONSTRAINT USERRECERT_GRP_PK PRIMARY KEY (ID)
);

ALTER TABLE USERRECERT_GROUP ADD CONSTRAINT USERRECERT_GRP_FK FOREIGN KEY (RECERT_ID) REFERENCES USERRECERT_HISTORY (ID);
ALTER TABLE USERRECERT_GROUP ADD CONSTRAINT USERRECERT_GA_FK FOREIGN KEY (ACCOUNT_ID) REFERENCES USERRECERT_ACCOUNT (ID) ON DELETE CASCADE;

CREATE INDEX URG_ID_DEC ON USERRECERT_GROUP (RECERT_ID ASC, ACCOUNT_ID DESC, DECISION ASC);

ALTER TABLE PROCESSLOG ADD REQUESTOR_DN NVARCHAR(200);

CREATE TABLE RECERTIFIER_DETAILS_INFO (
  DN VARCHAR(255) NOT NULL,
  RECERTIFIER_TYPE VARCHAR(255),
  RECERTIFIER_NAME VARCHAR(255),
  CONSTRAINT RECERT_DETAILS_PK PRIMARY KEY (DN)
)

CREATE TABLE SOD_POLICY (
		ID BIGINT NOT NULL,
		GLOBAL_ID BIGINT NOT NULL,
		NAME NVARCHAR(256),
		DESCRIPTION NVARCHAR(500),
		BUSINESS_UNIT_NAME NVARCHAR(256),
		ENABLED CHAR(1),
		DN NVARCHAR(2000),
		VERSION BIGINT NOT NULL,
		CONSTRAINT SP_PK PRIMARY KEY (ID)
	)

CREATE TABLE SOD_RULE (
		ID BIGINT NOT NULL,
		POLICY_ID BIGINT NOT NULL,
		GLOBAL_ID BIGINT NOT NULL,
		NAME NVARCHAR(500),
		DESCRIPTION NVARCHAR(500),
		CARDINALITY SMALLINT,
		VERSION BIGINT NOT NULL,
		CONSTRAINT SPR_PK PRIMARY KEY (ID),
		CONSTRAINT SPR_FK FOREIGN KEY (POLICY_ID) REFERENCES SOD_POLICY (ID)
	)

CREATE TABLE SOD_OWNER (
		ID BIGINT NOT NULL,
		POLICY_ID BIGINT NOT NULL,
		OWNER_NAME NVARCHAR(256),
		BUSINESS_UNIT_NAME NVARCHAR(256),
		TYPE CHAR(2),
		DN NVARCHAR(2000),
		CONSTRAINT SPO_PK PRIMARY KEY (ID),
		CONSTRAINT SPO_FK FOREIGN KEY (POLICY_ID) REFERENCES SOD_POLICY (ID)
	)

CREATE TABLE SOD_RULE_ROLE (
		ID BIGINT NOT NULL,
		POLICY_RULE_ID BIGINT NOT NULL,
		GLOBAL_ID BIGINT NOT NULL,
		NAME NVARCHAR(256),
		DESCRIPTION NVARCHAR(500),
		BUSINESS_UNIT_NAME NVARCHAR(256),
		DN NVARCHAR(2000),
		CONSTRAINT SPRR_PK PRIMARY KEY (ID),
		CONSTRAINT SPRR_FK FOREIGN KEY (POLICY_RULE_ID) REFERENCES SOD_RULE (ID)
	)

CREATE TABLE SOD_VIOLATION_HISTORY (
		ID BIGINT NOT NULL,
		POLICY_GLOBAL_ID BIGINT NOT NULL,
		RULE_GLOBAL_ID BIGINT NOT NULL,
		PERSON_GLOBAL_ID BIGINT NOT NULL,
		PERSON_NAME NVARCHAR(256),
		PERSON_BU NVARCHAR(256),
		PERSON_DN NVARCHAR(2000),
		PROCESS_ID BIGINT,
		ADMIN_NAME NVARCHAR(256),
		ADMIN_BU NVARCHAR(256),
		ADMIN_DN NVARCHAR(2000),
		ADMIN_NOTES NVARCHAR(4000),
		STATUS CHAR(1),
		TS BIGINT NOT NULL,
		CONSTRAINT SVIOHIST_PK PRIMARY KEY (ID)
	)

CREATE TABLE SOD_VIOLATION_STATUS (
		ID BIGINT NOT NULL,
		POLICY_GLOBAL_ID BIGINT NOT NULL,
		RULE_GLOBAL_ID BIGINT NOT NULL,
		PERSON_GLOBAL_ID BIGINT NOT NULL,
		PERSON_NAME NVARCHAR(256),
		PERSON_BU NVARCHAR(256),
		PERSON_DN NVARCHAR(2000),
		PROCESS_ID BIGINT,
		ADMIN_NAME NVARCHAR(256),
		ADMIN_BU NVARCHAR(256),
		ADMIN_DN NVARCHAR(2000),
		ADMIN_NOTES NVARCHAR(4000),
		STATUS CHAR(1),
		TS BIGINT NOT NULL,
		EVAL_TS BIGINT NOT NULL,
		CONSTRAINT SVIOSTAT_PK PRIMARY KEY (ID)
	)

CREATE TABLE SOD_VIOLATION_ROLE_MAP (
		ID BIGINT NOT NULL,
		VIOLATION_ID BIGINT NOT NULL,
		RULEROLE NVARCHAR(2000),
		PERSONROLE NVARCHAR(2000),
		CONSTRAINT SPRVR_PK PRIMARY KEY (ID),
		CONSTRAINT SPRVR_FK FOREIGN KEY (VIOLATION_ID) REFERENCES SOD_VIOLATION_HISTORY (ID)
	);
CREATE INDEX SP_1 ON SOD_POLICY (GLOBAL_ID ASC, VERSION DESC);
CREATE INDEX SR_1 ON SOD_RULE (GLOBAL_ID ASC, POLICY_ID ASC);
CREATE INDEX SVS_1 ON SOD_VIOLATION_STATUS (POLICY_GLOBAL_ID ASC, EVAL_TS DESC);
CREATE INDEX SVS_2 ON SOD_VIOLATION_STATUS (PERSON_GLOBAL_ID ASC, RULE_GLOBAL_ID ASC);
CREATE INDEX SVS_3 ON SOD_VIOLATION_STATUS (RULE_GLOBAL_ID ASC, STATUS ASC, ID ASC);
CREATE INDEX SVRM_1 ON SOD_VIOLATION_ROLE_MAP (VIOLATION_ID ASC, PERSONROLE ASC, RULEROLE ASC);
ALTER TABLE SOD_VIOLATION_STATUS ADD CONSTRAINT SVS_UC UNIQUE (RULE_GLOBAL_ID, PERSON_GLOBAL_ID);


CREATE INDEX RESPROVSTATUSX ON RESOURCE_PROVIDERS (RESOURCE_STATUS ASC, RESTART_TIME ASC, PROVIDER_ID ASC);
CREATE INDEX LCR_CHILD_ID_X ON LCR_INPROGRESS_TABLE (CHILD_ID ASC);
CREATE INDEX SCH_MSG_SVR_X ON SCHEDULED_MESSAGE (SERVER ASC);
CREATE INDEX PROCESS_SUB_X ON PROCESS (SUBMITTED DESC, PARENT_ID ASC);
CREATE INDEX PROCESS_ID_ST ON PROCESS (ID ASC, STATE ASC);
CREATE INDEX PROCESS_PACT_ID_X ON PROCESS (PARENT_ACTIVITY_ID ASC, ID DESC);
CREATE INDEX PROCESS_USERREQ_X ON PROCESS (REQUESTER ASC, PARENT_ID ASC, TENANT ASC);
CREATE INDEX ACTIVITY_PID_X ON ACTIVITY (PROCESS_ID DESC);
CREATE INDEX PROCESSDATA_ID_DEF ON PROCESSDATA (PROCESS_ID ASC, DEF_ID ASC, VALUE_LAST_MODIFIED ASC);
CREATE INDEX PROCESSLOG_PID_X ON PROCESSLOG (PROCESS_ID ASC);
CREATE INDEX PROCESSLOG_AID_X ON PROCESSLOG (ACTIVITY_ID ASC);
CREATE INDEX ACTIVITY_LOCK_PIDX ON ACTIVITY_LOCK (PROCESS_ID ASC);
CREATE INDEX RECON_COMPLETED ON RECONCILIATION (COMPLETED ASC);
CREATE INDEX RECON_INFO_ACCT_ID ON RECONCILIATION_INFO (ACCOUNTID ASC, RECONID DESC);
CREATE INDEX RECON_INFO_ID_OP ON RECONCILIATION_INFO (RECONID ASC, OPERATION ASC);
CREATE INDEX WF_CALLBACK_PID_X ON WORKFLOW_CALLBACK (PROCESS_ID ASC);
CREATE INDEX POL_ANALY_ACC_X ON POLICY_ANALYSIS (LAST_ACCESSED ASC, ANALYSIS_ID);
CREATE INDEX ACCT_CHANGE_PREV_X ON ACCT_CHANGE (POLICY_ANALYSIS_ID ASC, OPERATION_TYPE ASC, REASON ASC);
CREATE INDEX ADT_EVENT_PID_ID_X ON AUDIT_EVENT (WORKFLOW_PROCESS_ID ASC, ID DESC);
CREATE INDEX ADT_MGMT_TGT_ID_X ON AUDIT_MGMT_TARGET (EVENT_ID ASC);
CREATE INDEX ADT_MGMT_PROV_ID_X ON AUDIT_MGMT_PROVISIONING (EVENT_ID ASC);
CREATE INDEX ADT_MGMT_DEL_ID_X ON AUDIT_MGMT_DELEGATE (EVENT_ID ASC);
CREATE INDEX TASKS_VIEWABLE_X ON TASKS_VIEWABLE (VIEW_ID ASC, VIEWABLE ASC, TASK_ID ASC);

ALTER TABLE SOD_POLICY ALTER COLUMN DESCRIPTION NVARCHAR(1024);
ALTER TABLE SOD_RULE_ROLE ALTER COLUMN DESCRIPTION NVARCHAR(1024);
ALTER TABLE USERRECERT_ROLE ALTER COLUMN ROLE_DESCRIPTION NVARCHAR(1024);
ALTER TABLE USERRECERT_GROUP ALTER COLUMN GROUP_DESCRIPTION NVARCHAR(1024);

ALTER TABLE ENTITLEMENT_PROVISIONINGPARAMS
  ADD SERVICETARGETNAME VARCHAR(255),
      SERVICE_DN VARCHAR(255);

/**
--
-- PENDING_REQUESTS
--
-- This table keeps the pending deprovisioning and suspend requests.
--
-- PROCESS_ID - The process ID associated with the data
-- PERSON_DN  - The definition ID for the corresponding relevant data in process definition
-- SERVICE_DN - The activity ID associated with the data if there is any
-- ACCOUNT_DN - The definition ID for corresponding relevant data in process definition
-- PROCESS_TYPE - The process type
--
*/
CREATE TABLE PENDING_REQUESTS
(
  PROCESS_ID  BIGINT NOT NULL,
  PERSON_DN   NVARCHAR(2000),
  SERVICE_DN  NVARCHAR(2000),
  ACCOUNT_DN  NVARCHAR(2000),
  PROCESS_TYPE NVARCHAR(2),
CONSTRAINT PENDING_REQS_FK FOREIGN KEY(PROCESS_ID)
  REFERENCES PROCESS(ID) ON DELETE CASCADE,
CONSTRAINT PENDING_REQS_PK PRIMARY KEY(PROCESS_ID)
);

CREATE INDEX PENDING_REQUESTS_FOR_ACCOUNT ON PENDING_REQUESTS (ACCOUNT_DN);

ALTER TABLE ENTITY_COLUMN ADD COLUMN_LENGTH SMALLINT DEFAULT 255 WITH VALUES;